#!/bin/bash -e

errors=""

if [ ! -f libflashplayer.so ]; then
  errors="${errors}libflashplayer.so not found\n"
fi

if ! type -P strings >/dev/null; then
  errors="${errors}strings not found\n"
fi

if ! type -P fakeroot >/dev/null; then
  errors="${errors}fakeroot not found\n"
fi

if ! type -P ar >/dev/null; then
  errors="${errors}ar not found\n"
fi

if [ -n "${errors}" ]; then
  echo -e "${errors}can't build ${pkg}"
  exit 1
fi

version=$(strings libflashplayer.so | grep -e "^Shockwave Flash [.\d+]*" | sed -e "s/Shockwave Flash //g" -e 's/ r/./')-1
pkg=adobe-flash-player_${version}_i386.deb

echo creating data dir
mkdir -p d/usr/lib/mozilla/plugins
cp libflashplayer.so d/usr/lib/mozilla/plugins
chmod a+x d/usr/lib/mozilla/plugins
fakeroot tar zcf data.tar.gz -C d .

echo creating control dir
mkdir c
cat >c/control <<EOF
Package: adobe-flash-player
Version: ${version}
Section: xandros
Priority: optional
Architecture: i386
Depends: libgtk2.0-0
Installed-Size: $(du -s d|cut -f1)
Maintainer: Nobody <nobody@example.xa>
Description: Adobe Flash plug-in for Mozilla browsers.
 This package contains the Adobe Flash player plug-in for Mozilla browsers.
 It has been patched to work with glibc < 2.4!
EOF
(cd d;find * -type f|xargs md5sum) > c/md5sums
fakeroot tar zcf control.tar.gz -C c .

echo cleaning up temporary dirs
rm -rf c d ${pkg}

echo building package
echo 2.0 >debian-binary
ar rc ${pkg} debian-binary control.tar.gz data.tar.gz

echo cleaning up temporary files
rm -r debian-binary control.tar.gz data.tar.gz

